@@ -763,13 +763,6 @@ currently allocated.`,
 			`Show the instance's current status including logs, checks,
 and events.`,
 		}
-	case "suspend":
-		return KeyStrings{"suspend [APPNAME]", "Suspend an application",
-			`The SUSPEND command will suspend an application.
-All instances will be halted leaving the application running nowhere.
-It will continue to consume networking resources (IP address). See RESUME
-for details on restarting it.`,
-		}
 	case "turboku":
 		return KeyStrings{"turboku <heroku-app>", "Launches heroku apps",
 			`Launches heroku apps`,
