@@ -11,9 +11,9 @@ import (
 	"github.com/superfly/flyctl/pkg/iostreams"
 
 	"github.com/superfly/flyctl/internal/cli/internal/command"
-	"github.com/superfly/flyctl/internal/cli/internal/flag"
 	"github.com/superfly/flyctl/internal/cli/internal/render"
 	apiClient "github.com/superfly/flyctl/internal/client"
+	"github.com/superfly/flyctl/internal/flag"
 )
 
 func newInstances() (cmd *cobra.Command) {
