@@ -9,14 +9,14 @@ import (
 	"github.com/superfly/flyctl/pkg/iostreams"
 
 	"github.com/superfly/flyctl/internal/cli/internal/command"
-	"github.com/superfly/flyctl/internal/cli/internal/config"
 	"github.com/superfly/flyctl/internal/cli/internal/render"
 	"github.com/superfly/flyctl/internal/client"
+	"github.com/superfly/flyctl/internal/config"
 )
 
 func newWhoAmI() *cobra.Command {
 	const (
-		long = `Displays the users email address/service identity currently 
+		long = `Displays the users email address/service identity currently
 authenticated and in use.
 `
 		short = "Show the currently authenticated user"
