@@ -18,8 +18,8 @@ import (
 	"github.com/superfly/flyctl/internal/cli/internal/app"
 	"github.com/superfly/flyctl/internal/cli/internal/command"
 	"github.com/superfly/flyctl/internal/cli/internal/command/dig"
-	"github.com/superfly/flyctl/internal/cli/internal/flag"
 	"github.com/superfly/flyctl/internal/client"
+	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/pkg/agent"
 	"golang.org/x/net/icmp"
 	"golang.org/x/net/ipv6"
