@@ -4,7 +4,6 @@ import (
 	"context"
 	"encoding/base64"
 	"fmt"
-	"net"
 	"time"
 
 	"github.com/azazeal/pause"
@@ -50,9 +49,3 @@ func waitForMachineState(parent context.Context, client *api.Client, appID, mach
 func encodeCommand(command string) string {
 	return base64.StdEncoding.Strict().EncodeToString([]byte(command))
 }
-
-func machineIP(machine *api.Machine) string {
-	ip := machine.IPs.Nodes[0].IP
-	peerIP := net.ParseIP(ip)
-	return peerIP.String()
-}
