@@ -8,7 +8,7 @@ import (
 
 	"github.com/superfly/flyctl/internal/cli/internal/cache"
 	"github.com/superfly/flyctl/internal/cli/internal/command"
-	"github.com/superfly/flyctl/internal/cli/internal/flag"
+	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/pkg/iostreams"
 )
 
